@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,7 @@
 
 package org.hsqldb;
 
+import java.util.TimeZone;
 import java.util.Vector;
 import java.util.concurrent.atomic.AtomicInteger;
 
@@ -58,7 +59,7 @@ import org.hsqldb.persist.HsqlProperties;
  * Maintains a reference to the timer used for file locks and logging.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.7.0
  * @since 1.7.2
  */
 public class DatabaseManager {
@@ -127,7 +128,7 @@ public class DatabaseManager {
      * Used by server to open a new session
      */
     public static Session newSession(int dbID, String user, String password,
-                                     String zoneString, int timeZoneSeconds) {
+                                     String zoneString) {
 
         Database db = null;
 
@@ -139,8 +140,8 @@ public class DatabaseManager {
             return null;
         }
 
-        Session session = db.connect(user, password, zoneString,
-                                     timeZoneSeconds);
+        Session session = db.connect(user, password,
+                                     TimeZone.getTimeZone(zoneString));
 
         session.isNetwork = true;
 
@@ -152,11 +153,11 @@ public class DatabaseManager {
      */
     public static Session newSession(String type, String path, String user,
                                      String password, HsqlProperties props,
-                                     String zoneString, int timeZoneSeconds) {
+                                     TimeZone zone) {
 
         Database db = getDatabase(type, path, props);
 
-        return db.connect(user, password, zoneString, timeZoneSeconds);
+        return db.connect(user, password, zone);
     }
 
     /**
