@@ -50,7 +50,7 @@ import org.hsqldb.types.Type;
  * Implementation of column, variable, parameter, etc. access operations.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.6.1
+ * @version 2.7.1
  * @since 1.9.0
  */
 public class ExpressionColumn extends Expression {
@@ -699,6 +699,11 @@ public class ExpressionColumn extends Expression {
 
                 break;
             }
+            case OpTypes.COLUMN : {
+                if (dataType == null) {
+                    dataType = column.getDataType();
+                }
+            }
         }
     }
 
