@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,7 +33,7 @@ package org.hsqldb;
 
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
-import org.hsqldb.lib.HsqlList;
+import org.hsqldb.lib.List;
 import org.hsqldb.types.BinaryData;
 import org.hsqldb.types.Type;
 import org.hsqldb.types.Types;
@@ -43,7 +43,7 @@ import org.hsqldb.types.Types;
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.3
+ * @version 2.6.0
  * @since 1.9.0
  */
 public final class ExpressionLike extends ExpressionLogical {
@@ -54,8 +54,7 @@ public final class ExpressionLike extends ExpressionLogical {
     /**
      * Creates a LIKE expression
      */
-    ExpressionLike(Expression left, Expression right, Expression escape,
-                   boolean noOptimisation) {
+    ExpressionLike(Expression left, Expression right, Expression escape) {
 
         super(OpTypes.LIKE);
 
@@ -64,7 +63,6 @@ public final class ExpressionLike extends ExpressionLogical {
         nodes[RIGHT]        = right;
         nodes[ESCAPE]       = escape;
         likeObject          = new Like();
-        this.noOptimisation = noOptimisation;
     }
 
     private ExpressionLike(ExpressionLike other) {
@@ -75,9 +73,9 @@ public final class ExpressionLike extends ExpressionLogical {
         this.likeObject = other.likeObject;
     }
 
-    public HsqlList resolveColumnReferences(Session session,
+    public List resolveColumnReferences(Session session,
             RangeGroup rangeGroup, int rangeCount, RangeGroup[] rangeGroups,
-            HsqlList unresolvedSet, boolean acceptsSequences) {
+            List unresolvedSet, boolean acceptsSequences) {
 
         for (int i = 0; i < nodes.length; i++) {
             if (nodes[i] != null) {
@@ -332,7 +330,7 @@ public final class ExpressionLike extends ExpressionLogical {
         sb.append(left).append(' ').append(Tokens.T_LIKE).append(' ');
         sb.append(right);
 
-        /** @todo fredt - scripting of non-ascii escapes needs changes to general script logging */
+        /* @todo fredt - scripting of non-ascii escapes needs changes to general script logging */
         if (nodes[ESCAPE] != null) {
             sb.append(' ').append(Tokens.T_ESCAPE).append(' ');
             sb.append(nodes[ESCAPE].getSQL());
