@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,7 +50,7 @@ import org.hsqldb.types.Type;
  * Parser for SQL stored procedures and functions - PSM
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.6.0
+ * @version 2.7.0
  * @since 1.9.0
  */
 public class ParserRoutine extends ParserTable {
@@ -2430,10 +2430,8 @@ public class ParserRoutine extends ParserTable {
 
             int position = getPosition();
 
-            isCheckOrTriggerCondition = true;
-            condition                 = XreadBooleanValueExpression();
-            conditionSQL              = getLastPart(position);
-            isCheckOrTriggerCondition = false;
+            condition    = XreadBooleanValueExpression();
+            conditionSQL = getLastPart(position);
 
             readThis(Tokens.CLOSEBRACKET);
 
