@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -59,7 +59,7 @@ import org.hsqldb.types.Types;
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.7.0
  * @since 1.7.2
  *
  */
@@ -102,16 +102,16 @@ public class SetFunctionValueAggregate implements SetFunction {
         this.isDistinct = isDistinct;
 
         if (isDistinct) {
-            distinctValues = new HashSet();
-
             if (type.isRowType() || type.isArrayType()
                     || type.isCharacterType()) {
                 comparator = new TypedComparator(session);
 
                 comparator.setType(type, null);
-                distinctValues.setComparator(comparator);
+
+                distinctValues = new HashSet(32, comparator);
             } else {
-                comparator = null;
+                comparator     = null;
+                distinctValues = new HashSet(32);
             }
         } else {
             comparator = null;
@@ -365,6 +365,8 @@ public class SetFunctionValueAggregate implements SetFunction {
                     case Types.SQL_INTERVAL_SECOND :
                     case Types.SQL_INTERVAL_MONTH :
                     case Types.SQL_DATE :
+                    case Types.SQL_TIME :
+                    case Types.SQL_TIME_WITH_TIME_ZONE :
                     case Types.SQL_TIMESTAMP :
                     case Types.SQL_TIMESTAMP_WITH_TIME_ZONE : {
                         addLongGroup(item);
