@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,7 @@ import org.hsqldb.ParserDQL.CompileContext;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.ArrayUtil;
-import org.hsqldb.lib.HashMappedList;
+import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.navigator.RowIterator;
 import org.hsqldb.navigator.RowSetNavigatorData;
 import org.hsqldb.navigator.RowSetNavigatorDataTable;
@@ -48,7 +48,7 @@ import org.hsqldb.types.Type;
  * Table with data derived from a query expression.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.7.1
  * @since 1.9.0
  */
 public class TableDerived extends Table {
@@ -87,8 +87,28 @@ public class TableDerived extends Table {
         }
     }
 
+    /**
+     * For named sunbqueries.
+     */
     public TableDerived(Database database, HsqlName name, int type,
-                        Type[] columnTypes, HashMappedList columnList,
+                        HsqlName[] colNames, Type[] colTypes) {
+
+        this(database, name, type);
+
+        // todo check column counts match
+        for (int i = 0; i < colNames.length; i++) {
+            ColumnSchema column = new ColumnSchema(colNames[i], colTypes[i]);
+
+            columnList.add(column.getName().name, column);
+        }
+
+        columnCount = colNames.length;
+
+        createPrimaryKey(null, null, false);
+    }
+
+    public TableDerived(Database database, HsqlName name, int type,
+                        Type[] columnTypes, OrderedHashMap columnList,
                         int[] pkColumns) {
 
         this(database, name, type);
@@ -300,7 +320,7 @@ public class TableDerived extends Table {
                 throw Error.error(ErrorCode.X_42593);
             }
 
-            HashMappedList newColumnList = new HashMappedList();
+            OrderedHashMap newColumnList = new OrderedHashMap();
 
             for (int i = 0; i < columnCount; i++) {
                 ColumnSchema col = (ColumnSchema) columnList.get(i);
@@ -394,9 +414,7 @@ public class TableDerived extends Table {
                 return;
             }
 
-            Result result;
-
-            result = queryExpression.getResult(session, 0);
+            Result result = queryExpression.getResult(session, 0);
 
             if (uniqueRows) {
                 RowSetNavigatorData navigator =
