@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -48,7 +48,7 @@ import org.hsqldb.rowio.RowInputInterface;
  *
  * @author Bob Preston (sqlbob@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.0
  */
 public class TextTable extends Table {
 
@@ -89,7 +89,7 @@ public class TextTable extends Table {
     private void connect(Session session, boolean withReadOnlyData) {
 
         // Open new cache:
-        if ((dataSource.length() == 0) || isConnected) {
+        if (dataSource.isEmpty() || isConnected) {
 
             // nothing to do
             return;
@@ -143,8 +143,8 @@ public class TextTable extends Table {
             // everything is in order here.
             // At this point table should either have a valid (old) data
             // source and cache or have an empty source and null cache.
-            throw Error.error(t, ErrorCode.TEXT_FILE, 0, new Object[] {
-                Long.valueOf(linenumber), t.toString()
+            throw Error.error(t, ErrorCode.TEXT_FILE, 0, new String[] {
+                String.valueOf(linenumber), t.toString()
             });
         }
 
@@ -244,7 +244,7 @@ public class TextTable extends Table {
             //
         } else {
             session.getGrantee().checkSchemaUpdateOrGrantRights(
-                getSchemaName().name);
+                getSchemaName());
         }
 
         dataSourceNew = dataSourceNew.trim();
@@ -264,6 +264,11 @@ public class TextTable extends Table {
         return dataSource;
     }
 
+    public void setDataSource(String source, boolean desc) {
+        dataSource = source;
+        isReversed = desc;
+    }
+
     public boolean isDescDataSource() {
         return isReversed;
     }
@@ -370,7 +375,7 @@ public class TextTable extends Table {
     }
 
     /**
-     * Generates the SET TABLE <tablename> SOURCE HEADER <string> statement for a
+     * Generates the {@code SET TABLE <tablename> SOURCE HEADER <string>} statement for a
      * text table;
      */
     String getDataSourceHeader() {
