@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2023, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,7 +39,7 @@ import org.hsqldb.persist.PersistentStore;
  * Manages rows involved in transactions
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.2
  * @since 2.0.0
  */
 public class TransactionManager2PL extends TransactionManagerCommon
@@ -283,16 +283,12 @@ implements TransactionManager {
                 return;
             }
 
-            cs = updateCurrentStatement(session, cs);
-
-            if (cs == null) {
-                return;
-            }
-
             boolean canProceed = setWaitedSessionsTPL(session, cs);
 
             if (canProceed) {
-                session.isPreTransaction = true;
+                if (!session.isTransaction) {
+                    session.isPreTransaction = true;
+                }
 
                 if (session.tempSet.isEmpty()) {
                     lockTablesTPL(session, cs);
@@ -313,6 +309,13 @@ implements TransactionManager {
     }
 
     public void beginActionResume(Session session) {
+        Statement cs = session.sessionContext.currentStatement;
+
+        cs = updateCurrentStatement(session, cs);
+
+        if (session.sessionContext.invalidStatement) {
+            return;
+        }
 
         if (session.isTransaction) {
             session.actionSCN      = getNextSystemChangeNumber();
