@@ -79,7 +79,7 @@ import org.hsqldb.lib.KMPSearchAlgorithm;
  * </div>
  * <!-- end release-specific documentation -->
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.7.1
  * @since HSQLDB 2.1
  */
 public class JDBCBlobFile implements java.sql.Blob {
@@ -618,10 +618,13 @@ public class JDBCBlobFile implements java.sql.Blob {
         checkClosed();
 
         InputStream result;
+        
+        final List streams = m_streams;
 
         try {
             result = new InputStreamAdapter(m_file, pos - 1, length) {
                 private boolean closed;
+                private final InputStream self = this;
 
                 public void close() throws IOException {
                     if (closed) {
@@ -631,7 +634,7 @@ public class JDBCBlobFile implements java.sql.Blob {
                     try {
                         super.close();
                     } finally {
-                        m_streams.remove(this);
+                        streams.remove(self);
                     }
                 }
             };
@@ -639,7 +642,7 @@ public class JDBCBlobFile implements java.sql.Blob {
             throw JDBCUtil.sqlException(ex);
         }
 
-        m_streams.add(result);
+        streams.add(result);
 
         return result;
     }
