@@ -91,7 +91,7 @@ import org.hsqldb.lib.List;
  * </div>
  * <!-- end release-specific documentation -->
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.7.1
  * @since HSQLDB 2.1
  */
 public class JDBCClobFile implements java.sql.Clob {
@@ -211,12 +211,16 @@ public class JDBCClobFile implements java.sql.Clob {
     public InputStream getAsciiStream() throws SQLException {
 
         InputStream stream;
+        
+        final List streams = m_streams;
 
         try {
             stream = new JDBCBlobFile.InputStreamAdapter(m_file, 0,
                     Long.MAX_VALUE) {
 
                 private boolean closed;
+                
+                private InputStream self = this;
 
                 public synchronized void close() throws IOException {
 
@@ -229,7 +233,7 @@ public class JDBCClobFile implements java.sql.Clob {
                     try {
                         super.close();
                     } finally {
-                        m_streams.remove(this);
+                       streams.remove(self);
                     }
                 }
             };
@@ -245,7 +249,7 @@ public class JDBCClobFile implements java.sql.Clob {
             throw JDBCUtil.sqlException(ex);
         }
 
-        m_streams.add(stream);
+        streams.add(stream);
 
         return stream;
     }
@@ -870,6 +874,8 @@ public class JDBCClobFile implements java.sql.Clob {
         }
 
         Reader reader;
+        
+        final List streams = m_streams;
 
         try {
             reader = new ReaderAdapter(m_file, pos - 1, length) {
@@ -879,7 +885,7 @@ public class JDBCClobFile implements java.sql.Clob {
                     try {
                         super.close();
                     } finally {
-                        m_streams.remove(this);
+                        streams.remove(this);
                     }
                 }
             };
@@ -889,7 +895,7 @@ public class JDBCClobFile implements java.sql.Clob {
             throw JDBCUtil.sqlException(ex);
         }
 
-        m_streams.add(reader);
+        streams.add(reader);
 
         return reader;
     }
