@@ -1,7 +1,7 @@
 /*
  * For work developed by the HSQL Development Group:
  *
- * Copyright (c) 2001-2020, The HSQL Development Group
+ * Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -84,7 +84,7 @@ import org.hsqldb.map.BitMap;
  *
  * @author Thomas Mueller (Hypersonic SQL Group)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.7.0
  * @since 1.7.2
  */
 public class StringConverter {
@@ -119,7 +119,7 @@ public class StringConverter {
      * @param s hexadecimal string
      *
      * @return byte array for the hex string
-     * @throws IOException
+     * @throws IOException on error
      */
     public static byte[] hexStringToByteArray(String s) throws IOException {
 
@@ -170,7 +170,7 @@ public class StringConverter {
      * Compacts a bit string into a BitMap
      * @param s bit string
      * @return BitMap for the bit string
-     * @throws IOException
+     * @throws IOException on error
      */
     public static BitMap sqlBitStringToBitMap(String s) throws IOException {
 
@@ -488,7 +488,7 @@ public class StringConverter {
         int count = 0;
 
         while (count < length) {
-            c = (int) bytearr[offset + count];
+            c = bytearr[offset + count];
 
             if (bcount == buf.length) {
                 buf = (char[]) ArrayUtil.resizeArray(buf, length);
@@ -518,7 +518,7 @@ public class StringConverter {
                         throw new UTFDataFormatException();
                     }
 
-                    char2 = (int) bytearr[offset + count - 1];
+                    char2 = bytearr[offset + count - 1];
 
                     if ((char2 & 0xC0) != 0x80) {
                         throw new UTFDataFormatException();
@@ -537,8 +537,8 @@ public class StringConverter {
                         throw new UTFDataFormatException();
                     }
 
-                    char2 = (int) bytearr[offset + count - 2];
-                    char3 = (int) bytearr[offset + count - 1];
+                    char2 = bytearr[offset + count - 2];
+                    char3 = bytearr[offset + count - 1];
 
                     if (((char2 & 0xC0) != 0x80) || ((char3 & 0xC0) != 0x80)) {
                         throw new UTFDataFormatException();
@@ -633,7 +633,7 @@ public class StringConverter {
      *
      * @param is InputStream to read from
      * @param encoding character encoding of the string
-     * @throws IOException
+     * @throws IOException on error
      * @return a Java string
      */
     public static String inputStreamToString(InputStream is,
@@ -954,4 +954,42 @@ public class StringConverter {
 
         return b.toString();
     }
+
+    public static void toJSONString(String s, StringBuilder sb) {
+
+        int firstQuote;
+        int length = s.length();
+
+        sb.append('"');
+
+        firstQuote = s.indexOf('"');
+
+        if (firstQuote == -1) {
+            if (s.indexOf('\\') == -1) {
+                sb.append(s);
+                sb.append('"');
+
+                return;
+            }
+        }
+
+        sb.append(s.substring(0, firstQuote));
+
+        for (int i = firstQuote; i < length; i++) {
+            char c = s.charAt(i);
+
+            if (c < 32) {
+                sb.append('\\');
+                appendHex(sb, c);
+            } else {
+                if (c == '"' || c == '\\') {
+                    sb.append('\\');
+                }
+
+                sb.append(c);
+            }
+        }
+
+        sb.append('"');
+    }
 }
