@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,7 +46,7 @@ import java.math.BigDecimal;
   * @version 2.4.1
   * @since 1.7.2
   */
-public class ValuePool {
+public final class ValuePool {
 
     //
     static ValuePoolHashMap intPool;
