@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,24 +31,24 @@
 
 package org.hsqldb.persist;
 
-import org.hsqldb.lib.DoubleIntIndex;
+import org.hsqldb.lib.LongLookup;
 
 /**
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.3
+ * @version 2.5.1
  * @since 2.3.0
  */
 public class DataSpaceManagerSimple implements DataSpaceManager {
 
-    DataFileCache     cache;
-    TableSpaceManager defaultSpaceManager;
-    int               fileBlockSize = DataSpaceManager.fixedBlockSizeUnit;
-    long              totalFragmentSize;
-    int               spaceIdSequence = tableIdFirst;
-    DoubleIntIndex    lookup;
+    final DataFileCache     cache;
+    final TableSpaceManager defaultSpaceManager;
+    final int               fileBlockSize = fixedDiskBlockSize;
+    long                    totalFragmentSize;
+    int                     spaceIdSequence = tableIdFirst;
+    LongLookup              lookup;
 
     /**
-     * Used for default, readonly, Text and Session data files
+     * Used for non-space default, readonly, Text and Session data files
      */
     DataSpaceManagerSimple(DataFileCache cache, boolean isReadOnly) {
 
@@ -62,8 +62,8 @@ public class DataSpaceManagerSimple implements DataSpaceManager {
             int capacity = cache.database.logger.propMaxFreeBlocks;
 
             defaultSpaceManager = new TableSpaceManagerBlocks(this,
-                    DataSpaceManager.tableIdDefault, fileBlockSize, capacity,
-                    cache.getDataFileScale(), 0);
+                    tableIdDefault, fileBlockSize, capacity,
+                    cache.getDataFileScale());
 
             if (!isReadOnly) {
                 initialiseSpaces();
@@ -82,64 +82,55 @@ public class DataSpaceManagerSimple implements DataSpaceManager {
     public TableSpaceManager getTableSpace(int spaceId) {
 
         if (spaceId >= spaceIdSequence) {
-            spaceIdSequence = spaceId + 1;
+            spaceIdSequence = spaceId + 2;
         }
 
         return defaultSpaceManager;
     }
 
     public int getNewTableSpaceID() {
-        return spaceIdSequence++;
+
+        int id = spaceIdSequence;
+
+        spaceIdSequence += 2;
+
+        return id;
     }
 
     public long getFileBlocks(int spaceId, int blockCount) {
 
-        long filePosition = cache.enlargeFileSpace((long) blockCount
-            * fileBlockSize);
+        long filePosition = cache.getFileFreePos();
+
+        cache.enlargeFileSpace(filePosition
+                               + (long) blockCount * fileBlockSize);
 
         return filePosition;
     }
 
+    public void initialiseTableSpace(TableSpaceManagerBlocks tableSpace) {}
+
     public void freeTableSpace(int spaceId) {}
 
-    public void freeTableSpace(int spaceId, DoubleIntIndex spaceList,
-                               long offset, long limit, boolean full) {
+    public void freeTableSpace(int spaceId, LongLookup spaceList, long offset,
+                               long limit) {
 
         totalFragmentSize += spaceList.getTotalValues()
                              * cache.getDataFileScale();
 
-        if (full) {
-            if (cache.fileFreePosition == limit) {
-                cache.writeLock.lock();
+        if (cache.fileFreePosition == limit) {
+            cache.writeLock.lock();
 
-                try {
-                    cache.fileFreePosition = offset;
-                } finally {
-                    cache.writeLock.unlock();
-                }
-            } else {
-                totalFragmentSize += limit - offset;
-            }
-
-            if (spaceList.size() != 0) {
-                lookup = new DoubleIntIndex(spaceList.size(), true);
-
-                spaceList.copyTo(lookup);
-                spaceList.clear();
+            try {
+                cache.fileFreePosition = offset;
+            } finally {
+                cache.writeLock.unlock();
             }
         } else {
-            spaceList.compactLookupAsIntervals();
-            spaceList.setValuesSearchTarget();
-            spaceList.sort();
+            totalFragmentSize += limit - offset;
+        }
 
-            int extra = spaceList.size() - spaceList.capacity() / 2;
-
-            if (extra > 0) {
-                spaceList.removeRange(0, extra);
-
-                totalFragmentSize -= spaceList.getTotalValues()
-                                     * cache.getDataFileScale();
-            }
+        if (spaceList.size() != 0) {
+            lookup = spaceList.duplicate();
         }
     }
 
@@ -157,10 +148,11 @@ public class DataSpaceManagerSimple implements DataSpaceManager {
 
     public void initialiseSpaces() {
 
-        long currentSize = cache.getFileFreePos();
-        long totalBlocks = (currentSize + fileBlockSize) / fileBlockSize;
+        long filePosition = cache.getFileFreePos();
+        long totalBlocks = (filePosition + fileBlockSize) / fileBlockSize;
+
         long lastFreePosition = cache.enlargeFileSpace(totalBlocks
-            * fileBlockSize - currentSize);
+            * fileBlockSize);
 
         defaultSpaceManager.initialiseFileBlock(lookup, lastFreePosition,
                 cache.getFileFreePos());
