@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,7 +31,6 @@
 
 package org.hsqldb.persist;
 
-import java.io.IOException;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 
@@ -50,7 +49,6 @@ import org.hsqldb.index.Index;
 import org.hsqldb.index.NodeAVL;
 import org.hsqldb.index.NodeAVLDisk;
 import org.hsqldb.lib.ArrayUtil;
-import org.hsqldb.lib.DoubleIntIndex;
 import org.hsqldb.lib.DoubleLongIndex;
 import org.hsqldb.lib.LongKeyHashMap;
 import org.hsqldb.lib.LongLookup;
@@ -113,6 +111,13 @@ public class RowStoreAVLDisk extends RowStoreAVL {
         return object;
     }
 
+    public CachedObject get(long key) {
+
+        CachedObject object = cache.get(key, this, false);
+
+        return object;
+    }
+
     public CachedObject get(CachedObject object, boolean keep) {
 
         object = cache.get(object, this, keep);
@@ -134,7 +139,7 @@ public class RowStoreAVLDisk extends RowStoreAVL {
         object.setPos(pos);
 
         if (tx) {
-            RowAction action = RowAction.addInsertAction(session, table,
+            RowAction action = RowAction.addInsertAction(session, table, this,
                 (Row) object);
 
             if (database.txManager.isMVRows()) {
@@ -176,21 +181,17 @@ public class RowStoreAVLDisk extends RowStoreAVL {
 
     public CachedObject get(RowInputInterface in) {
 
-        try {
-            Row row;
+        Row row;
 
-            if (largeData) {
-                row = new RowAVLDiskLarge(this, in);
-            } else {
-                row = new RowAVLDisk(this, in);
-            }
-
-            set(row);
-
-            return row;
-        } catch (IOException e) {
-            throw Error.error(ErrorCode.DATA_FILE_ERROR, e);
+        if (largeData) {
+            row = new RowAVLDiskLarge(this, in);
+        } else {
+            row = new RowAVLDisk(this, in);
         }
+
+        set(row);
+
+        return row;
     }
 
     public CachedObject getNewCachedObject(Session session, Object object,
@@ -233,8 +234,17 @@ public class RowStoreAVLDisk extends RowStoreAVL {
 
     public void removeAll() {
 
+        if (cache.spaceManager.isMultiSpace()) {
+            if (tableSpace.isDefaultSpace()) {
+                LongLookup pointerLookup = getPointerList();
+
+                removeDefaultSpaces(pointerLookup);
+            } else {
+                cache.spaceManager.freeTableSpace(tableSpace.getSpaceID());
+            }
+        }
+
         elementCount.set(0);
-        cache.spaceManager.freeTableSpace(tableSpace.getSpaceID());
         ArrayUtil.fillArray(accessorList, null);
     }
 
@@ -375,7 +385,8 @@ public class RowStoreAVLDisk extends RowStoreAVL {
 
         if (!isMV) {
             synchronized (row) {
-                return RowAction.addDeleteAction(session, table, row, colMap);
+                return RowAction.addDeleteAction(session, table, this, row,
+                                                 colMap);
             }
         }
 
@@ -386,7 +397,8 @@ public class RowStoreAVLDisk extends RowStoreAVL {
         mapLock.lock();
 
         try {
-            action = RowAction.addDeleteAction(session, table, row, colMap);
+            action = RowAction.addDeleteAction(session, table, this, row,
+                                               colMap);
 
             if (action != null) {
                 rowActionMap.put(action.getPos(), action);
@@ -442,6 +454,21 @@ public class RowStoreAVLDisk extends RowStoreAVL {
         return node;
     }
 
+    /**
+     *  Sets the index roots of a cached table to specified file pointers.
+     *  If a file pointer is -1 then the particular index root is null. A null
+     *  index root signifies an empty table. Accordingly, all index roots should
+     *  be null or all should be a valid file pointer/reference.
+     */
+    public void setAccessors(long base, long[] accessors, long cardinality) {
+
+        for (int index = 0; index < indexList.length; index++) {
+            setAccessor(indexList[index], accessors[index]);
+        }
+
+        setElementCount(cardinality);
+    }
+
     public void setAccessor(Index key, long accessor) {
 
         CachedObject object = get(accessor, false);
