@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,6 +32,7 @@
 package org.hsqldb.result;
 
 import java.io.IOException;
+import java.util.Arrays;
 
 import org.hsqldb.ColumnBase;
 import org.hsqldb.error.Error;
@@ -47,7 +48,7 @@ import org.hsqldb.types.Types;
  * Metadata for a result set.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.6.1
  * @since 1.8.0
  */
 public final class ResultMetaData {
@@ -145,23 +146,24 @@ public final class ResultMetaData {
         return md;
     }
 
-    public static ResultMetaData newDoubleColumnMetaData(String colNameA,
-            String colNameB) {
+    public static ResultMetaData newMetaData(String[] colNames,
+            Type[] colTypes) {
 
-        ResultMetaData md = ResultMetaData.newResultMetaData(2);
+        ResultMetaData md = newResultMetaData(colTypes, null, colTypes.length,
+                                              colTypes.length);
 
-        md.columns[0] = new ColumnBase(null, null, null, colNameA);
+        for (int i = 0; i < colNames.length; i++) {
+            ColumnBase col = new ColumnBase(null, null, null, colNames[i]);
 
-        md.columns[0].setType(Type.SQL_VARCHAR_DEFAULT);
+            col.setType(colTypes[i]);
 
-        md.columns[1] = new ColumnBase(null, null, null, colNameB);
+            md.columns[i] = col;
+        }
 
-        md.columns[1].setType(Type.SQL_VARCHAR_DEFAULT);
         md.prepareData();
 
         return md;
     }
-
     public static ResultMetaData newResultMetaData(Type[] types,
             int[] baseColumnIndexes, int colCount, int extColCount) {
 
@@ -401,7 +403,7 @@ public final class ResultMetaData {
         }
     }
 
-    Type readDataTypeSimple(RowInputInterface in) throws IOException {
+    Type readDataTypeSimple(RowInputInterface in) {
 
         int     typeCode = in.readType();
         boolean isArray  = typeCode == Types.SQL_ARRAY;
@@ -415,7 +417,7 @@ public final class ResultMetaData {
         return Type.getDefaultType(typeCode);
     }
 
-    Type readDataType(RowInputInterface in) throws IOException {
+    Type readDataType(RowInputInterface in) {
 
         int     typeCode = in.readType();
         boolean isArray  = typeCode == Types.SQL_ARRAY;
@@ -457,7 +459,7 @@ public final class ResultMetaData {
         }
     }
 
-    void write(RowOutputInterface out) throws IOException {
+    void write(RowOutputInterface out) {
 
         out.writeInt(type);
         out.writeInt(columnCount);
@@ -544,6 +546,28 @@ public final class ResultMetaData {
         return newMeta;
     }
 
+    public static boolean areGeneratedReguestsCompatible(ResultMetaData a,
+            ResultMetaData b) {
+
+        if (a == b) {
+            return true;
+        }
+
+        if (a == null || b == null) {
+            return false;
+        }
+
+        if (!Arrays.equals(a.columnLabels, b.columnLabels)) {
+            return false;
+        }
+
+        if (!Arrays.equals(a.colIndexes, b.colIndexes)) {
+            return false;
+        }
+
+        return true;
+    }
+
     public boolean areTypesCompatible(ResultMetaData newMeta) {
 
         if (columnCount != newMeta.columnCount) {
