@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,10 +32,7 @@
 package org.hsqldb.rowio;
 
 import java.math.BigDecimal;
-import java.util.Calendar;
-import java.util.GregorianCalendar;
 
-import org.hsqldb.HsqlDateTime;
 import org.hsqldb.HsqlException;
 import org.hsqldb.Scanner;
 import org.hsqldb.Session;
@@ -50,7 +47,6 @@ import org.hsqldb.types.BlobData;
 import org.hsqldb.types.BlobDataID;
 import org.hsqldb.types.ClobData;
 import org.hsqldb.types.ClobDataID;
-import org.hsqldb.types.DateTimeType;
 import org.hsqldb.types.IntervalMonthData;
 import org.hsqldb.types.IntervalSecondData;
 import org.hsqldb.types.IntervalType;
@@ -63,7 +59,7 @@ import org.hsqldb.types.Type;
  * Class for reading the data for a database row from the script file.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.7.0
  * @since 1.7.3
  */
 public class RowInputTextLog extends RowInputBase
@@ -74,9 +70,7 @@ implements RowInputInterface {
     String   schemaName = null;
     int      statementType;
     Object   value;
-    boolean  version18;
     boolean  noSeparators;
-    Calendar tempCalDefault = new GregorianCalendar();
 
     public RowInputTextLog() {
 
@@ -85,14 +79,6 @@ implements RowInputInterface {
         scanner = new Scanner();
     }
 
-    public RowInputTextLog(boolean version18) {
-
-        super(new byte[0]);
-
-        scanner        = new Scanner();
-        this.version18 = version18;
-    }
-
     public void setSource(Session session, String text) {
 
         scanner.reset(session, text);
@@ -337,17 +323,6 @@ implements RowInputInterface {
             return null;
         }
 
-        if (version18) {
-            java.sql.Time dateTime = java.sql.Time.valueOf((String) value);
-            long millis =
-                HsqlDateTime.convertMillisFromCalendar(tempCalDefault,
-                    dateTime.getTime());
-
-            millis = HsqlDateTime.getNormalisedTime(millis);
-
-            return new TimeData((int) millis / 1000, 0, 0);
-        }
-
         return scanner.newTime((String) value);
     }
 
@@ -359,17 +334,6 @@ implements RowInputInterface {
             return null;
         }
 
-        if (version18) {
-            java.sql.Date dateTime = java.sql.Date.valueOf((String) value);
-            long millis =
-                HsqlDateTime.convertMillisFromCalendar(tempCalDefault,
-                    dateTime.getTime());
-
-            millis = HsqlDateTime.getNormalisedDate(millis);
-
-            return new TimestampData(millis / 1000);
-        }
-
         return scanner.newDate((String) value);
     }
 
@@ -381,19 +345,6 @@ implements RowInputInterface {
             return null;
         }
 
-        if (version18) {
-            java.sql.Timestamp dateTime =
-                java.sql.Timestamp.valueOf((String) value);
-            long millis =
-                HsqlDateTime.convertMillisFromCalendar(tempCalDefault,
-                    dateTime.getTime());
-            int nanos = dateTime.getNanos();
-
-            nanos = DateTimeType.normaliseFraction(nanos, type.scale);
-
-            return new TimestampData(millis / 1000, nanos, 0);
-        }
-
         return scanner.newTimestamp((String) value);
     }
 
