@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -323,8 +323,7 @@ public class TriggerSample implements Trigger {
     }
 
     public static String getTriggerDDL(String trn, int typ, String tab,
-                                       int qs,
-                                       String impl) throws SQLException {
+                                       int qs, String impl) {
 
         StringBuilder sb = new StringBuilder();
 
