@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -479,6 +479,11 @@ class TestBench {
             Stmt.execute(Query);
             Stmt.clearWarnings();
 
+            Query = "SET TABLE tellers NEW SPACE";
+
+            Stmt.execute(Query);
+            Stmt.clearWarnings();
+
             Query = "CREATE TABLE accounts ("
                     + "Aid         INTEGER NOT NULL PRIMARY KEY, "
                     + "Bid         INTEGER, " + "Abalance    INTEGER, "
@@ -1289,7 +1294,7 @@ class TestBench {
         }    /* end of DoOne         */
     }    /* end of class ClientThread */
 
-    class MemoryWatcherThread extends Thread {
+    static class MemoryWatcherThread extends Thread {
 
         long    min          = 0;
         long    max          = 0;
