@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,7 @@ package org.hsqldb.types;
 import java.io.DataInput;
 import java.io.IOException;
 import java.io.InputStream;
+import java.util.Arrays;
 
 import org.hsqldb.SessionInterface;
 import org.hsqldb.error.Error;
@@ -45,7 +46,7 @@ import org.hsqldb.lib.ArrayUtil;
  * A Binary object instance always wraps a non-null byte[] object.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.0.1
+ * @version 2.6.1
  * @since 1.7.2
  */
 public class BinaryData implements BlobData {
@@ -84,7 +85,7 @@ public class BinaryData implements BlobData {
     public BinaryData(byte[] data, boolean clone) {
 
         if (clone) {
-            data = (byte[]) ArrayUtil.duplicateArray(data);
+            data = Arrays.copyOf(data, data.length);
         }
 
         this.data      = data;
@@ -255,8 +256,14 @@ public class BinaryData implements BlobData {
         return position(session, bytes, start);
     }
 
-    /** @todo - implement */
     public long nonZeroLength(SessionInterface session) {
+
+        for (int i = data.length - 1; i > 0; i--) {
+            if (data[i] != 0) {
+                return i + 1;
+            }
+        }
+
         return data.length;
     }
 
@@ -280,7 +287,6 @@ public class BinaryData implements BlobData {
 
     public void setSession(SessionInterface session) {}
 
-    //---
     static boolean isInLimits(long fullLength, long pos, long len) {
         return pos >= 0 && len >= 0 && pos + len <= fullLength;
     }
