@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -123,7 +123,7 @@ public class BlobInputStream extends InputStream {
         return (int) avail;
     }
 
-    public void close() throws IOException {
+    public void close() {
         isClosed = true;
     }
 
