@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -142,7 +142,7 @@ public final class ClobInputStream extends Reader {
         return (int) avail;
     }
 
-    public void close() throws IOException {
+    public void close() {
         isClosed = true;
     }
 
