@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -122,7 +122,7 @@ public final class ClobType extends CharacterType {
         return true;
     }
 
-    /** @todo - collation comparison */
+    /* @todo - collation comparison */
     public int compare(Session session, Object a, Object b) {
         return compare(session, a, b, OpTypes.EQUAL);
     }
@@ -144,8 +144,8 @@ public final class ClobType extends CharacterType {
         if (b instanceof String) {
             long lobId = ((ClobData) a).getId();
 
-            return session.database.lobManager.compare(collation,
-                    lobId, (String) b);
+            return session.database.lobManager.compare(collation, lobId,
+                    (String) b);
         }
 
         return session.database.lobManager.compare(collation, (ClobData) a,
