@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -137,7 +137,7 @@ class JDBCTypes {
         return (String) hStringJDBCtypes.get(Integer.valueOf(type));
     }
 
-    public int toInt(String type) throws Exception {
+    public int toInt(String type) {
 
         Integer tempInteger = (Integer) hIntJDBCtypes.get(type);
 
