@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2007, The HSQL Development Group
+/* Copyright (c) 2001-2022, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-
+ 
 
 package org.hsqldb.util.preprocessor;
 
@@ -36,10 +36,12 @@ import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.util.Stack;
 
-/* $Id: Preprocessor.java 5793 2018-01-06 13:12:38Z fredt $ */
-
+/*
+ * $Id: Preprocessor.java 6550 2022-06-08 11:09:08Z fredt $
+ */
 /**
- * Simple text document preprocessor. <p>
+ * Simple text document preprocessor.
+ * <p>
  *
  * Aims specifically at transforming the HSQLDB codebase to one of a small
  * number of specific build targets, while keeping complexity and external
@@ -47,21 +49,21 @@ import java.util.Stack;
  * sufficiently powerful to solve most easily imaginable preprocessing
  * scenarios.
  *
- * Supports the following (case-sensitive) directives: <p>
+ * Supports the following (case-sensitive) directives:
  *
  * <ul>
- *  <li>//#def[ine] IDENT (ASSIGN? (STRING | NUMBER | IDENT) )?
- *  <li>//#elif BOOLEXPR
- *  <li>//#elifdef IDENT
- *  <li>//#elifndef IDENT
- *  <li>//#else
- *  <li>//#endif
- *  <li>//#endinclude
- *  <li>//#if BOOLEXPR
- *  <li>//#ifdef IDENT
- *  <li>//#ifndef IDENT
- *  <li>//#include FILEPATH
- *  <li>//#undef[ine] IDENT
+ * <li>//#def[ine] IDENT (ASSIGN? (STRING | NUMBER | IDENT) )?
+ * <li>//#elif BOOLEXPR
+ * <li>//#elifdef IDENT
+ * <li>//#elifndef IDENT
+ * <li>//#else
+ * <li>//#endif
+ * <li>//#endinclude
+ * <li>//#if BOOLEXPR
+ * <li>//#ifdef IDENT
+ * <li>//#ifndef IDENT
+ * <li>//#include FILEPATH
+ * <li>//#undef[ine] IDENT
  * </ul>
  *
  * where BOOLEXPR is:
@@ -72,7 +74,7 @@ import java.util.Stack;
  * | BOOLEXPR { OR | XOR | AND } BOOLEXPR
  * | NOT BOOLEXPR
  * | LPAREN BOOLEXPR RPAREN )
- *</pre>
+ * </pre>
  *
  * and VALUE is :
  *
@@ -82,18 +84,18 @@ import java.util.Stack;
  * | IDENT )
  * </pre>
  *
- * and lexographic elements are :
+ * and lexicographic elements are :
  *
  * <pre>
  * ASSIGN     : '='
  * EQ         : '=='
- * LT         : '<'
- * LTE        : '<='
- * GT         : '>'
- * GTE        : '>='
+ * LT         : {@code '<'}
+ * LTE        : {@code '<='}
+ * GT         : {@code '>'}
+ * GTE        : {@code '>='}
  * OR         : ('|' | '||')
  * XOR        : '^'
- * AND        : ('&' | '&&')
+ * AND        : {@code ('&' | '&&')}
  * NOT        : '!'
  * DQUOTE     : '"'
  * LPAREN     : '('
@@ -112,38 +114,43 @@ import java.util.Stack;
  * FILEPATH   : NON_SPACE (ANY_UNICODE_CHARACTER* NON_WS)?     -- i.e. trailing SPACE elements are ignored
  * </pre>
  *
- * The lexographic definitions above use the BNF conventions :
+ * The lexicographic definitions above use the BNF conventions :
  *
  * <pre>
- * '?' -> zero or one
- * '*' -> zero or more
- * '+' -> one or more
+ * '?' : zero or one
+ * '*' : zero or more
+ * '+' : one or more
  * </pre>
  *
  * Directives may be arbitrarily indented; there is an option (INDENT) to set
  * or unset directive indentation on output. There is also an option (FILTER)
- * to remove directive lines from output.  See {@link Option Option} for other
- * preprocessor options. <p>
+ * to remove directive lines from output. See {@link Option Option} for other
+ * preprocessor options.
+ * <p>
  *
  * '//#ifxxx' directives may be nested to arbitrary depth,
  * may be chained with an arbitrary number of '//#elifxxx' directives,
  * may be optionally followed by a single '//#else' directive, and
- * must be terminated by a single '//#endif' directive. <p>
+ * must be terminated by a single '//#endif' directive.
+ * <p>
  *
  * Each '//#include' directive must be terminated by an '//#endinclude'
  * directive; lines between '//#include' and '//#endinclude' are replaced
- * by the content retrieved from the specified FILEPATH. <p>
+ * by the content retrieved from the specified FILEPATH.
+ * <p>
  *
  * Included files are preprocessed in a nested scope that inherits the
  * defined symbols of the including scope. Directive lines in included files
- * are always excluded from output. <p>
+ * are always excluded from output.
+ * <p>
  *
  * <b>Design Notes</b><p>
  *
  * There are many better/more sophisticated preprocessors/templating
- * engines out there.  FreeMaker and Velocity come to mind immediately.
+ * engines out there. FreeMaker and Velocity come to mind immediately.
  * Another--the NetBeans MIDP preprocessor--was the direct inspiration for
- * this class. <p>
+ * this class.
+ * <p>
  *
  * Other options were rejected because the work of creating this class appeared
  * to be less than dealing with the complexity and dependency issues of hooking
@@ -152,10 +159,11 @@ import java.util.Stack;
  * The NetBeans preprocessor, in particular, was rejected because it was
  * not immediately evident how to invoke it independently from the IDE,
  * how to make it available to non-MIDP projects from within the IDE or how to
- * isolate the correct OpenIDE jars to allow stand-alone operation. <p>
+ * isolate the correct OpenIDE jars to allow stand-alone operation.
+ * <p>
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
- * @version 1.8.1
+ * @version 2.7.0
  * @since 1.8.1
  */
 public class Preprocessor {
@@ -163,26 +171,34 @@ public class Preprocessor {
     // =========================================================================
     // ------------------------------- Public API ------------------------------
     // =========================================================================
-
     /**
-     * Preprocesses the specified list of files. <p>
+     * Preprocesses the specified list of files.
+     * <p>
      *
      * @param sourceDir under which input files are located
      * @param targetDir under which output files are to be written
      * @param fileNames to be preprocessed
-     * @param altExt to use for output file names
-     * @param encoding with which to write output files
-     * @param options used to control preprocessing
-     * @param defines CSV list of symbol definition expressions
-     * @param resolver with which to perform property and path expansions
+     * @param altExt    to use for output file names
+     * @param encoding  with which to write output files
+     * @param options   used to control preprocessing
+     * @param defines   CSV list of symbol definition expressions
+     * @param resolver  with which to perform property and path expansions
      * @throws PreprocessorException if an error occurs while loading,
-     *      preprocessing or saving the result of preprocessing one of the
-     *      specified input files
+     *                               preprocessing or saving the result of preprocessing one of the
+     *                               specified input files
      */
     public static void preprocessBatch(File sourceDir, File targetDir,
             String[] fileNames, String altExt, String encoding, int options,
             String defines, IResolver resolver) throws PreprocessorException {
 
+//        log("sourceDir: " + sourceDir);
+//        log("targetDir: " + targetDir);
+//        log("fileNames: " + Arrays.asList(fileNames));
+//        log("altExt   : " + altExt);
+//        log("encoding : " + encoding);
+//        log("options  : " + Option.toOptionsString(options));
+//        log("defines  : " + defines);
+//        log("resolver : " + resolver);
         for (int i = 0; i < fileNames.length; i++) {
             String fileName = fileNames[i];
 
@@ -201,44 +217,54 @@ public class Preprocessor {
     }
 
     /**
-     * Preprocesses a single file. <p>
+     * Preprocesses a single file.
+     * <p>
      *
      * @param sourceDir under which the input file is located
      * @param targetDir under which the output file is to be written
-     * @param fileName to be preprocessed
-     * @param altExt to use for output file name
-     * @param encoding with which to write output file
-     * @param options used to control preprocessing
-     * @param defines CSV list of symbol definition expressions
-     * @param resolver with which to perform property and path expansions
+     * @param fileName  to be preprocessed
+     * @param altExt    to use for output file name
+     * @param encoding  with which to write output file
+     * @param options   used to control preprocessing
+     * @param defines   CSV list of symbol definition expressions
+     * @param resolver  with which to perform property and path expansions
      * @throws PreprocessorException if an error occurs while loading,
-     *      preprocessing or saving the result of preprocessing the
-     *      specified input file
+     *                               preprocessing or saving the result of preprocessing the
+     *                               specified input file
      */
     public static void preprocessFile(File sourceDir, File targetDir,
             String fileName, String altExt, String encoding, int options,
             String defines, IResolver resolver) throws PreprocessorException {
 
-        String       sourcePath   = translatePath(sourceDir, fileName, null);
-        String       targetPath   = translatePath(targetDir, fileName, altExt);
-        File         targetFile   = new File(targetPath);
-        File         backupFile   = new File(targetPath + "~");
-        boolean      sameDir      = sourceDir.equals(targetDir);
-        boolean      sameExt      = (altExt ==  null);
-        boolean      verbose      = Option.isVerbose(options);
-        boolean      testOnly     = Option.isTestOnly(options);
-        boolean      backup       = Option.isBackup(options);
+        String sourcePath = translatePath(sourceDir, fileName, null);
+        String targetPath = translatePath(targetDir, fileName, altExt);
+        File targetFile = new File(targetPath);
+        File backupFile = new File(targetPath + "~");
+        boolean sameDir = sourceDir.equals(targetDir);
+        boolean sameExt = (altExt == null);
+        boolean verbose = Option.isVerbose(options);
+        boolean testOnly = Option.isTestOnly(options);
+        boolean backup = Option.isBackup(options);
         Preprocessor preprocessor = new Preprocessor(sourcePath,
                 encoding, options, resolver, defines);
 
         if (verbose) {
-            log("Reading \"" + sourcePath + "\"");
+//        log("sourceDir : " + sourceDir);
+//        log("targetDir : " + targetDir);
+//        log("fileName  : " + fileName);
+//        log("altExt    : " + altExt);
+//        log("encoding  : " + encoding);
+//        log("options   : " + Option.toOptionsString(options));
+//        log("defines   : " + defines);
+//        log("resolver  : " + resolver);
+            log("sourcePath: " + sourcePath);
+            log("targetPath: " + targetPath);
         }
 
         preprocessor.loadDocument();
 
         boolean modified = preprocessor.preprocess();
-        boolean rewrite  = modified || !sameDir || !sameExt;
+        boolean rewrite = modified || !sameDir || !sameExt;
 
         if (!rewrite) {
             if (verbose) {
@@ -268,7 +294,7 @@ public class Preprocessor {
                     + targetFile
                     + "\" => \""
                     + backupFile
-                    +"\"" ); // NOI18N
+                    + "\""); // NOI18N
         }
 
         if (verbose) {
@@ -285,17 +311,16 @@ public class Preprocessor {
     // =========================================================================
     // ----------------------------- Implementation ----------------------------
     // =========================================================================
-
     // Fields
-
     // static
-    static final int CONDITION_NONE      = 0;
-    static final int CONDITION_ARMED     = 1;
-    static final int CONDITION_IN_TRUE   = 2;
+    static final int CONDITION_NONE = 0;
+    static final int CONDITION_ARMED = 1;
+    static final int CONDITION_IN_TRUE = 2;
     static final int CONDITION_TRIGGERED = 3;
 
     // optimization - zero new object burn rate for statePush()
-    static final Integer[] STATES = new Integer[] {
+    @SuppressWarnings("UnnecessaryBoxing")
+    static final Integer[] STATES = new Integer[]{
         new Integer(CONDITION_NONE),
         new Integer(CONDITION_ARMED),
         new Integer(CONDITION_IN_TRUE),
@@ -303,17 +328,16 @@ public class Preprocessor {
     };
 
     // instance
-    private String    documentPath;
-    private String    encoding;
-    private int       options;
-    private IResolver resolver;
-    private Document  document;
-    private Defines   defines;
-    private Stack     stack;
-    private int       state;
+    private final String documentPath;
+    private final String encoding;
+    private final int options;
+    private final IResolver resolver;
+    private final Document document;
+    private final Defines defines;
+    private final Stack stack;
+    private int state;
 
     // Constructors
-
     private Preprocessor(String documentPath,
             String encoding, int options, IResolver resolver,
             String predefined) throws PreprocessorException {
@@ -329,31 +353,30 @@ public class Preprocessor {
         if (predefined == null || predefined.trim().length() == 0) {
             this.defines = new Defines();
         } else {
-            predefined   = this.resolver.resolveProperties(predefined);
+            predefined = this.resolver.resolveProperties(predefined);
             this.defines = new Defines(predefined);
         }
 
         this.documentPath = documentPath;
-        this.encoding     = encoding;
-        this.options      = options;
-        this.document     = new Document();
-        this.stack        = new Stack();
-        this.state        = CONDITION_NONE;
+        this.encoding = encoding;
+        this.options = options;
+        this.document = new Document();
+        this.stack = new Stack();
+        this.state = CONDITION_NONE;
     }
 
     private Preprocessor(Preprocessor other, Document include) {
-        this.document     = include;
-        this.encoding     = other.encoding;
-        this.stack        = new Stack();
-        this.state        = CONDITION_NONE;
-        this.options      = other.options;
+        this.document = include;
+        this.encoding = other.encoding;
+        this.stack = new Stack();
+        this.state = CONDITION_NONE;
+        this.options = other.options;
         this.documentPath = other.documentPath;
-        this.resolver     = other.resolver;
-        this.defines      = other.defines;
+        this.resolver = other.resolver;
+        this.defines = other.defines;
     }
 
     // Main entry point
-
     private boolean preprocess() throws PreprocessorException {
         this.stack.clear();
 
@@ -386,39 +409,39 @@ public class Preprocessor {
             }
         }
 
-        return (!this.document.equals(originalDocument));
+        return (!this.document.contentEquals(originalDocument));
     }
 
     private void preprocessImpl() throws PreprocessorException {
-        int     includeCount = 0;
-        int     lineCount    = 0;
+        int includeCount = 0;
+        int lineCount = 0;
 
         while (lineCount < this.document.size()) {
 
             try {
                 Line line = resolveLine(this.document.getSourceLine(lineCount));
 
-                switch(line.getType()) {
-                    case LineType.INCLUDE : {
+                switch (line.getType()) {
+                    case LineType.INCLUDE: {
                         lineCount = processInclude(lineCount, line);
 
                         break;
                     }
-                    case LineType.VISIBLE :
-                    case LineType.HIDDEN : {
+                    case LineType.VISIBLE:
+                    case LineType.HIDDEN: {
                         this.document.setSourceLine(lineCount,
                                 toSourceLine(line));
 
                         if (Option.isVerbose(options)) {
-                                log((isHidingLines() ? "Commented: "
-                                                     : "Uncommented: ") + line);
+                            log((isHidingLines() ? "Commented: "
+                                    : "Uncommented: ") + line);
                         }
 
                         lineCount++;
 
                         break;
                     }
-                    default : {
+                    default: {
                         processDirective(line);
 
                         lineCount++;
@@ -435,28 +458,27 @@ public class Preprocessor {
     }
 
     // -------------------------- Line-level Handlers --------------------------
-
     private void processIf(boolean condition) {
         statePush();
 
         this.state = isHidingLines() ? CONDITION_TRIGGERED
-                                     : (condition) ? CONDITION_IN_TRUE
-                                                   : CONDITION_ARMED;
+                : (condition) ? CONDITION_IN_TRUE
+                        : CONDITION_ARMED;
     }
 
     private void processElseIf(boolean condition) throws PreprocessorException {
-        switch(state) {
-            case CONDITION_NONE : {
+        switch (state) {
+            case CONDITION_NONE: {
                 throw new PreprocessorException("Unexpected #elif"); // NOI18N
             }
-            case CONDITION_ARMED : {
+            case CONDITION_ARMED: {
                 if (condition) {
                     this.state = CONDITION_IN_TRUE;
                 }
 
                 break;
             }
-            case CONDITION_IN_TRUE : {
+            case CONDITION_IN_TRUE: {
                 this.state = CONDITION_TRIGGERED;
 
                 break;
@@ -465,16 +487,16 @@ public class Preprocessor {
     }
 
     private void processElse() throws PreprocessorException {
-        switch(state) {
-            case CONDITION_NONE : {
+        switch (state) {
+            case CONDITION_NONE: {
                 throw new PreprocessorException("Unexpected #else"); // NOI18N
             }
-            case CONDITION_ARMED : {
+            case CONDITION_ARMED: {
                 this.state = CONDITION_IN_TRUE;
 
                 break;
             }
-            case CONDITION_IN_TRUE : {
+            case CONDITION_IN_TRUE: {
                 this.state = CONDITION_TRIGGERED;
 
                 break;
@@ -491,62 +513,62 @@ public class Preprocessor {
     }
 
     private void processDirective(Line line) throws PreprocessorException {
-        switch(line.getType()) {
-            case LineType.DEFINE : {
+        switch (line.getType()) {
+            case LineType.DEFINE: {
                 if (!isHidingLines()) {
                     this.defines.defineSingle(line.getArguments());
                 }
 
                 break;
             }
-            case LineType.UNDEFINE : {
+            case LineType.UNDEFINE: {
                 if (!isHidingLines()) {
                     this.defines.undefine(line.getArguments());
                 }
 
                 break;
             }
-            case LineType.IF : {
+            case LineType.IF: {
                 processIf(this.defines.evaluate(line.getArguments()));
 
                 break;
             }
-            case LineType.IFDEF : {
+            case LineType.IFDEF: {
                 processIf(this.defines.isDefined(line.getArguments()));
 
                 break;
             }
-            case LineType.IFNDEF : {
+            case LineType.IFNDEF: {
                 processIf(!this.defines.isDefined(line.getArguments()));
 
                 break;
             }
-            case LineType.ELIF : {
+            case LineType.ELIF: {
                 processElseIf(this.defines.evaluate(line.getArguments()));
 
                 break;
             }
-            case LineType.ELIFDEF : {
+            case LineType.ELIFDEF: {
                 processElseIf(this.defines.isDefined(line.getArguments()));
 
                 break;
             }
-            case LineType.ELIFNDEF : {
+            case LineType.ELIFNDEF: {
                 processElseIf(!this.defines.isDefined(line.getArguments()));
 
                 break;
             }
-            case LineType.ELSE : {
+            case LineType.ELSE: {
                 processElse();
 
                 break;
             }
-            case LineType.ENDIF : {
+            case LineType.ENDIF: {
                 processEndIf();
 
                 break;
             }
-            default : {
+            default: {
                 throw new PreprocessorException("Unhandled line type: "
                         + line); // NOI18N
             }
@@ -554,9 +576,9 @@ public class Preprocessor {
     }
 
     private int processInclude(int lineCount, Line line)
-    throws PreprocessorException {
-        String    path   = resolvePath(line.getArguments());
-        boolean   hidden = isHidingLines();
+            throws PreprocessorException {
+        String path = resolvePath(line.getArguments());
+        boolean hidden = isHidingLines();
 
         lineCount++;
 
@@ -575,7 +597,7 @@ public class Preprocessor {
         }
 
         if (!hidden) {
-            Document     include      = loadInclude(path);
+            Document include = loadInclude(path);
             Preprocessor preprocessor = new Preprocessor(this, include);
 
             preprocessor.preprocess();
@@ -597,29 +619,29 @@ public class Preprocessor {
     }
 
     // -------------------------- Preprocessor State ---------------------------
-
     private boolean isHidingLines() {
-        switch(state) {
-            case CONDITION_ARMED :
+        switch (state) {
+            case CONDITION_ARMED:
             case CONDITION_TRIGGERED: {
                 return true;
             }
-            default : {
+            default: {
                 return false;
             }
         }
     }
 
+    @SuppressWarnings("unchecked")
     private void statePush() {
         this.stack.push(STATES[this.state]);
     }
 
+    @SuppressWarnings("UnnecessaryUnboxing")
     private void statePop() {
         this.state = ((Integer) stack.pop()).intValue();
     }
 
     // ------------------------------ Resolution -------------------------------
-
     private Line resolveLine(String line) throws PreprocessorException {
         return new Line(this.resolver.resolveProperties(line));
     }
@@ -629,49 +651,70 @@ public class Preprocessor {
             throw new IllegalArgumentException("path: null");
         }
 
-        String value = this.resolver.resolveProperties(path);
-        File   file  = this.resolver.resolveFile(value);
+        if (Option.isVerbose(options)) {
+            log("resolve path: " + path);
+        }
+
+        if (path.contains("${")) {
+            path = this.resolver.resolveProperties(path);
+
+            if (Option.isVerbose(options)) {
+                log("resolved properties: " + path);
+            }
+        }
+
+
+
+        File file = this.toCanonicalOrAbsoluteFile(path);
+
+        if (Option.isVerbose(options)) {
+            log("resolved file: " + file.getAbsolutePath());
+        }
 
         try {
-            return file.getCanonicalPath();
+            path = file.getCanonicalPath();
         } catch (IOException ex) {
-            return file.getAbsolutePath();
+            path = file.getAbsolutePath();
         }
+
+        if (Option.isVerbose(options)) {
+            log("resolved path: " + path);
+        }
+
+        return path;
     }
 
     // ------------------------------ Conversion -------------------------------
-
-    private String toSourceLine(Line line) {
+    private String toSourceLine(final Line line) {
+        final String indent = line.getIndent();
+        final String text = line.getText();
         return (isHidingLines())
-            ? Option.isIndent(this.options)
-                ? line.indent + Line.HIDE_DIRECTIVE + line.text
-                : Line.HIDE_DIRECTIVE + line.indent + line.text
-            : line.indent + line.text;
+                ? Option.isIndent(this.options)
+                ? indent + Line.HIDE_DIRECTIVE + text
+                : Line.HIDE_DIRECTIVE + indent + text
+                : indent + text;
     }
 
     private File toCanonicalOrAbsoluteFile(String path) {
         File file = new File(path);
 
         if (!file.isAbsolute()) {
-            path = (new File(this.documentPath)).getParent()
-                    + File.separatorChar
-                    + path;
+            File parent = (new File(this.documentPath)).getParentFile();
 
-            file = new File(path);
+            file = new File(parent, path);
         }
 
         try {
             return file.getCanonicalFile();
-        } catch (Exception e) {
+        } catch (IOException e) {
             return file.getAbsoluteFile();
         }
     }
 
     // ------------------------------ Translation ------------------------------
-
     private static String translatePath(File dir, String fileName, String ext) {
         return new StringBuffer(dir.getPath()).append(File.separatorChar).
-                append(translateFileExtension(fileName,ext)).toString();
+                append(translateFileExtension(fileName, ext)).toString();
     }
 
     private static String translateFileExtension(String fileName, String ext) {
@@ -680,17 +723,16 @@ public class Preprocessor {
             int pos = fileName.lastIndexOf('.');
 
             fileName = (pos < 0) ? fileName + ext
-                                 : fileName.substring(0, pos) + ext;
+                    : fileName.substring(0, pos) + ext;
         }
 
         return fileName;
     }
 
     // ---------------------------------- I/O ----------------------------------
-
     private Document loadInclude(String path) throws PreprocessorException {
         Document include = new Document();
-        File     file    = toCanonicalOrAbsoluteFile(path);
+        File file = toCanonicalOrAbsoluteFile(path);
 
         try {
             return include.load(file, this.encoding);
